@@ -547,6 +547,8 @@ class Reader(object):
         for line in self.stream:
             if line.startswith(marker):
                 return (''.join(lines), line)
+            if line.startswith("//"):
+                raise ValueError("Read past record separator.")
             lines.append(line)
         return (''.join(lines), None)
 
@@ -558,20 +560,21 @@ class Record(object):
         self.locus = parse_locus(stream.next())
         self.keywords = parse_keywords(stream.read_to("FEATURES")[0])
 
-        if self.locus["division"] == "CON":
-            data = stream.read_to("//")[0]
-            pos = data.find("CONTIG")
-            self.features = parse_features(data[:pos])
-            self.contig = parse_contig(data[pos:])
-            self.base_count = None
-            self.seqiter = None
+        (data, mark) = stream.read_to(("BASE COUNT", "ORIGIN", "CONTIG"))
+        self.features = parse_features(data)
+
+        self.base_count = None
+        self.contig = None
+        self.seqiter = None
+        
+        if mark.startswith("BASE COUNT"):
+            self.base_count = parse_base_count(mark)
+            (data, mark) = stream.read_to(("CONTIG", "ORIGIN"))
+        
+        if mark.startswith("CONTIG"):
+            data = ''.join([mark, stream.read_to("//")[0]])
+            self.contig = parse_contig(data)
         else:
-            data, marker = stream.read_to(("ORIGIN", "BASE COUNT"))
-            self.features = parse_features(data)
-            self.contig = None
-            self.base_count = None
-            if marker.startswith("BASE COUNT"):
-                self.base_count = parse_base_count(marker)
             self.seqiter = Sequence(stream)
 
     def __repr__(self):
